@@ -79,7 +79,7 @@ curl -Lsf http://`kubectl get svc horizon --namespace=kolla -o \
 timeout 120s openstack endpoint list
 
 curl -o cirros.qcow2 \
-    http://download.cirros-cloud.net/0.3.4/cirros-0.3.4-x86_64-disk.img
+    http://download.cirros-cloud.net/0.3.5/cirros-0.3.5-x86_64-disk.img
 echo testing cluster glance-api
 curl http://`kubectl get svc glance-api --namespace=kolla -o \
     jsonpath='{.spec.clusterIP}'`:9292/
@@ -103,11 +103,14 @@ neutron subnet-create --gateway=172.18.1.1 \
     --allocation-pool start=172.18.1.65,end=172.18.1.254 \
     --name admin admin 172.18.1.0/24
 neutron router-interface-add admin admin
-neutron security-group-rule-create --protocol icmp \
-    --direction ingress default
-neutron security-group-rule-create --protocol tcp \
-    --port-range-min 22 --port-range-max 22 \
-    --direction ingress default
+
+openstack security group list -f value -c ID | while read SG_ID; do
+    neutron security-group-rule-create --protocol icmp \
+        --direction ingress $SG_ID
+    neutron security-group-rule-create --protocol tcp \
+        --port-range-min 22 --port-range-max 22 \
+        --direction ingress $SG_ID
+done
 
 openstack flavor create --public --id 1 --ram 512 --disk 1 --vcpus 1 m1.tiny || true
 
@@ -139,7 +142,7 @@ sshpass -p 'cubswin:)' ssh -o UserKnownHostsFile=/dev/null -o \
     StrictHostKeyChecking=no cirros@$FIP curl 169.254.169.254
 
 sshpass -p 'cubswin:)' ssh -o UserKnownHostsFile=/dev/null -o \
-    StrictHostKeyChecking=no cirros@$FIP ping -c 4 $FIP2
+    StrictHostKeyChecking=no cirros@$FIP ping -W 20 -c 10 $FIP2
 
 openstack volume show test -f value -c status
 TESTSTR=$(uuidgen)
