@@ -1,6 +1,6 @@
 #!/bin/bash -xe
 
-VERSION=0.5.0-1
+VERSION=0.6.0-1
 
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )/../.." && pwd )"
 IP=172.18.0.1
@@ -18,8 +18,9 @@ fi
 
 base_distro="$2"
 gate_job="$1"
+branch="$3"
 function general_config {
-    common_workflow_config $IP $base_distro $tunnel_interface
+    common_workflow_config $IP $base_distro $tunnel_interface $branch
 }
 
 function ceph_config {
@@ -111,6 +112,12 @@ helm install kolla/nova-novncproxy-svc --version $VERSION \
     --namespace kolla --name nova-novncproxy-svc \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
+if [ "x$branch" != "x2" -a "x$branch" != "x3" ]; then
+helm install kolla/nova-placement-svc --debug --version $VERSION \
+    --namespace kolla --name nova-placement-svc \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+fi
+
 helm install kolla/horizon-svc --version $VERSION \
     --namespace kolla --name horizon-svc \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
@@ -153,6 +160,16 @@ helm install kolla/rabbitmq-statefulset --version $VERSION \
 $DIR/tools/pull_containers.sh kolla
 $DIR/tools/wait_for_pods.sh kolla
 
+helm install kolla/keystone-fernet-setup-job --version $VERSION \
+    --namespace kolla \
+    --name keystone-fernet-setup-job \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+
+$DIR/tools/pull_containers.sh kolla
+$DIR/tools/wait_for_pods.sh kolla
+
+helm delete --purge keystone-fernet-setup-job
+
 helm install kolla/keystone-create-db-job --version $VERSION \
     --namespace kolla \
     --name keystone-create-db \
@@ -191,6 +208,11 @@ $DIR/tools/wait_for_pods.sh kolla
 $DIR/tools/build_local_admin_keystonerc.sh
 . ~/keystonerc_admin
 
+helm install kolla/keystone-fernet-rotate-job --version $VERSION \
+    --namespace kolla --name keystone-fernet-rotate-job \
+    --set upload_debug=true \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+
 helm install kolla/neutron-create-keystone-service-job --version $VERSION \
     --namespace kolla --name neutron-create-keystone-service \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
@@ -207,6 +229,15 @@ helm install kolla/cinder-create-keystone-servicev2-job --version $VERSION \
     --namespace kolla --name cinder-create-keystone-servicev2 \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
+if [ "x$branch" != "x2" -a "x$branch" != "x3" ]; then
+helm install kolla/nova-placement-create-keystone-service-job --debug --version $VERSION \
+    --namespace kolla --name nova-placement-create-keystone-service \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+helm install kolla/nova-placement-create-keystone-user-job --debug --version $VERSION \
+    --namespace kolla --name nova-placement-create-keystone-user \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+fi
+
 helm install kolla/cinder-create-keystone-user-job --version $VERSION \
     --namespace kolla --name cinder-create-keystone-user \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
@@ -255,9 +286,41 @@ helm install kolla/neutron-create-keystone-endpoint-admin-job --version $VERSION
     --namespace kolla --name neutron-create-keystone-endpoint-admin \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
+helm install kolla/heat-create-keystone-user-job --version $VERSION \
+    --namespace kolla --name heat-create-keystone-user
+
+if [ "x$branch" != "x2" -a "x$branch" != "x3" ]; then
+helm install kolla/nova-placement-create-keystone-endpoint-public-job --debug --version $VERSION \
+    --namespace kolla --name nova-placement-create-keystone-endpoint-public \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+helm install kolla/nova-placement-create-keystone-endpoint-internal-job --debug --version $VERSION \
+    --namespace kolla --name nova-placement-create-keystone-endpoint-internal \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+helm install kolla/nova-placement-create-keystone-endpoint-admin-job --debug --version $VERSION \
+    --namespace kolla --name nova-placement-create-keystone-endpoint-admin \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+fi
+
+for x in heat heat-cfn; do
+    helm install kolla/$x-create-keystone-service-job --version $VERSION \
+        --namespace kolla --name $x-create-keystone-service \
+        --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+    helm install kolla/$x-create-keystone-endpoint-public-job --version $VERSION \
+        --namespace kolla --name $x-create-keystone-endpoint-public \
+        --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+    helm install kolla/$x-create-keystone-endpoint-internal-job --version $VERSION \
+        --namespace kolla --name $x-create-keystone-endpoint-internal \
+        --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+    helm install kolla/$x-create-keystone-endpoint-admin-job --version $VERSION \
+        --namespace kolla --name $x-create-keystone-endpoint-admin \
+        --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+done
 $DIR/tools/wait_for_pods.sh kolla
 
-for x in cinder glance neutron nova; do
+
+helm delete --purge keystone-fernet-rotate-job
+
+for x in cinder glance neutron nova heat; do
     helm delete --purge $x-create-keystone-user
 done
 
@@ -311,7 +374,7 @@ helm install kolla/nova-create-keystone-endpoint-admin-job --version $VERSION \
     --namespace kolla --name nova-create-keystone-endpoint-admin \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
-for x in nova nova-api neutron; do
+for x in nova nova-api neutron heat; do
     helm install kolla/$x-create-db-job --version $VERSION \
         --namespace kolla \
         --name $x-create-db \
@@ -340,7 +403,7 @@ $DIR/tests/bin/endpoint_test.sh
 [ -d "$WORKSPACE/logs" ] && openstack catalog list > \
     $WORKSPACE/logs/openstack-catalog-after-bootstrap.json || true
 
-for x in nova nova-api cinder neutron glance; do
+for x in nova nova-api cinder neutron glance heat; do
     helm delete --purge $x-create-db
 done
 
@@ -348,7 +411,9 @@ for x in nova-api cinder neutron glance; do
     helm delete --purge $x-manage-db
 done
 
-for x in glance neutron cinder nova; do
+
+
+for x in glance neutron cinder nova heat heat-cfn; do
     helm delete --purge $x-create-keystone-service
     helm delete --purge $x-create-keystone-endpoint-public
     helm delete --purge $x-create-keystone-endpoint-internal
@@ -382,6 +447,12 @@ helm install kolla/glance-registry-deployment --version $VERSION \
 
 helm ls
 
+if [ "x$branch" != "x2" -a "x$branch" != "x3" ]; then
+helm install kolla/nova-placement-deployment --debug --version $VERSION \
+    --namespace kolla --name nova-placement-deployment \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+fi
+
 for x in nova-api nova-novncproxy; do
     helm install kolla/$x-deployment --version $VERSION \
       --namespace kolla --name $x \
@@ -454,3 +525,4 @@ $DIR/tools/wait_for_pods.sh kolla
 kollakube res delete bootstrap openvswitch-set-external-ip
 
 $DIR/tools/wait_for_pods.sh kolla
+
