@@ -1,11 +1,12 @@
 #!/bin/bash -xe
 
-VERSION=0.5.0-1
+VERSION=0.6.0-1
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )/../.." && pwd )"
 gate_job="$1"
 base_distro="$2"
-IP=${3:-172.18.0.1}
-tunnel_interface=${4:-docker0}
+branch="$3"
+IP=${4:-172.18.0.1}
+tunnel_interface=${5:-docker0}
 
 # Break out devenv behavior since we will use different polling logic
 # and we also assume ceph-multi use in the devenv
@@ -28,11 +29,11 @@ function wait_for_pods {
 }
 
 function general_config {
-    common_workflow_config $IP $base_distro $tunnel_interface
+    common_workflow_config $IP $base_distro $tunnel_interface $branch
 }
 
 function ceph_config {
-    common_ceph_config $gate_job
+    common_ceph_config $gate_job $branch
 }
 
 if [ "x$gate_job" == "xceph-multi" ]; then
@@ -59,11 +60,13 @@ helm install kolla/memcached --version $VERSION \
     --namespace kolla --name memcached \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
+wait_for_pods kolla mariadb,memcached running,succeeded
+
 helm install kolla/rabbitmq --version $VERSION \
     --namespace kolla --name rabbitmq \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
-wait_for_pods kolla mariadb,memcached,rabbitmq running,succeeded
+wait_for_pods kolla rabbitmq running,succeeded
 
 helm install kolla/keystone --version $VERSION \
     --namespace kolla --name keystone \
@@ -114,7 +117,18 @@ helm install kolla/neutron --version $VERSION \
     --namespace kolla --name neutron \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
-wait_for_pods kolla cinder,glance,neutron running,succeeded
+sudo docker ps | grep openvswitch
+sudo docker exec -tu root $(sudo docker ps | grep openvswitch-vswitchd@ \
+                          | awk '{print $1}') ovs-vsctl add-br br-tenants
+sudo ifconfig br-tenants up
+sudo ifconfig br-tenants $(grep ironic_tftp_server $DIR/helm/all_values.yaml \
+                         | awk '{print $2}')/24
+
+helm install kolla/ironic --version $VERSION  --namespace kolla \
+    --name ironic \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+
+wait_for_pods kolla cinder,glance,neutron,ironic running,succeeded
 
 helm ls
 
@@ -126,6 +140,10 @@ helm install kolla/nova-compute --version $VERSION  --namespace kolla \
     --name nova-compute \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
 
+helm install kolla/nova-compute-ironic --version $VERSION  --namespace kolla \
+    --name nova-compute-ironic \
+    --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
+
 helm install kolla/horizon --version $VERSION \
     --namespace kolla --name horizon \
     --values /tmp/general_config.yaml --values /tmp/ceph_config.yaml
@@ -134,4 +152,5 @@ helm install kolla/horizon --version $VERSION \
 
 wait_for_pods kolla nova,horizon running,succeeded
 
+
 kollakube res delete bootstrap openvswitch-set-external-ip
