@@ -13,4 +13,10 @@ function common_iscsi_config {
     echo "      volume_lvm:"
     echo "        all:"
     echo "          element_name: cinder-volume"
+    echo "    tgtd:"
+    echo "      all:"
+    echo "        image_tag: 3.0.2"
+    echo "    iscsid:"
+    echo "      all:"
+    echo "        image_tag: 3.0.2"
 }
