@@ -26,6 +26,7 @@ kubectl get deployments --all-namespaces -o yaml > \
 kubectl describe node $(hostname -s) > $WORKSPACE/logs/node.txt
 kubectl get pods -a --all-namespaces -o yaml > $WORKSPACE/logs/pods.yaml
 kubectl get configmaps -a --all-namespaces -o yaml > $WORKSPACE/logs/configmaps.yaml
+kubectl get secrets -a --all-namespaces -o yaml > $WORKSPACE/logs/secrets.yaml
 sudo docker images > $WORKSPACE/logs/docker_images.txt
 kubectl get pods -a --all-namespaces -o json | jq -r \
     '.items[].metadata | .namespace + " " + .name' | while read line; do
@@ -106,4 +107,40 @@ cp /usr/bin/rbd $WORKSPACE/logs/rbd.sh
 done
 ovs-vsctl show > $WORKSPACE/logs/ovs.txt
 arp -a > $WORKSPACE/logs/arp.txt
+sudo docker exec -tu root \
+     $(sudo docker ps | grep nova-libvirt: | awk '{print $1}') \
+     cat /tmp/vm-1.log > $WORKSPACE/logs/vm-1.log
+sudo cp /tmp/packets $WORKSPACE/logs/packets
+mkdir -p $WORKSPACE/logs/rbac
+kubectl get clusterroles -o yaml > $WORKSPACE/logs/rbac/clusterroles.yaml
+kubectl get roles -o yaml > $WORKSPACE/logs/rbac/roles.yaml
+kubectl get clusterrolebindings -o yaml > $WORKSPACE/logs/rbac/clusterrolebindings.yaml
+kubectl get rolebindings -o yaml > $WORKSPACE/logs/rbac/rolebindings.yaml
+
+#
+# Check power status and status of vbmc
+#
+sudo ipmitool -I lanplus -U admin -P password -H 127.0.0.1 power status \
+                 > $WORKSPACE/logs/ipmitool_status.txt
+sudo vbmc list > $WORKSPACE/logs/vbmc_list.txt
+sudo vbmc show vm-1 > $WORKSPACE/logs/vbmc_show.txt
+
+#
+# Ironic realted logs
+#
+$DIR/tools/build_local_admin_keystonerc.sh
+. ~/keystonerc_admin
+openstack baremetal node list > $WORKSPACE/logs/baremetal_node_list.txt
+node_id=$(openstack baremetal node list -c "UUID" -f value)
+openstack baremetal node show $node_id > $WORKSPACE/logs/baremetal_node_show.txt
+openstack baremetal introspection rule list > $WORKSPACE/logs/baremetal_inspection_rule.txt
+openstack server list > $WORKSPACE/logs/openstack_server_list.txt
+openstack port list > $WORKSPACE/logs/openstack_port_list.txt
+ironic node-validate $node_id > $WORKSPACE/logs/ironic_node_validate.txt
+ironic port-list > $WORKSPACE/logs/ironic_port_list.txt
+ironic port-show $(ironic port-list | grep be:ef | awk '{print $2}' ) \
+                 > $WORKSPACE/logs/ironic_port_show.txt
+sudo virsh list > $WORKSPACE/logs/virsh_list.txt
+sudo virsh dumpxml vm-1 > $WORKSPACE/logs/virsh_dumpxml.txt
+
 exit -1
