@@ -3,8 +3,7 @@
 NODE=$(hostname -s)
 
 TYPE="$2"
-
-BRANCH="$6"
+BRANCH="$3"
 
 echo "kolla_base_distro: $1" >> kolla-ansible/etc/kolla/globals.yml
 cat tests/conf/ceph-all-in-one/kolla_config >> kolla-ansible/etc/kolla/globals.yml
@@ -31,8 +30,16 @@ if [ "x$TYPE" == "xceph-multi" ]; then
         etc/kolla-kubernetes/kolla-kubernetes.yml
 fi
 
-kolla-ansible/tools/generate_passwords.py
-kolla-ansible/tools/kolla-ansible genconfig
+if [ "x$BRANCH" == "x2" -o "x$BRANCH" == "x3" ]; then
+    echo 'enable_placement: "no"' >> kolla-ansible/etc/kolla/globals.yml
+fi
+
+# Generate passwords using SPRNG tool
+tools/generate_passwords.py
+
+# Generate configuration based upon defaults and overrides
+ansible-playbook -e ansible_python_interpreter=/usr/bin/python -e @/etc/kolla/globals.yml -e @/etc/kolla/passwords.yml -e CONFIG_DIR=/etc/kolla ansible/site.yml
+ls -la /etc/kolla
 
 crudini --set /etc/kolla/nova-compute/nova.conf libvirt virt_type qemu
 crudini --set /etc/kolla/nova-compute/nova.conf libvirt cpu_mode none
