@@ -9,25 +9,27 @@ if [ "x$REPODIR" == "x" ]; then
     exit 1
 fi
 
-$DIR/helm_buildrepo.sh "$REPODIR" &
-export PID=$!
-trap "kill $PID" TERM
+mkdir -p "$REPODIR"
 
 $DIR/helm_prebuild_microservices.py
 $DIR/helm_build_microservices.py "$REPODIR"
 
-helm repo index "$REPODIR"
-helm repo update
-
 $DIR/helm_prebuild_services.py
 $DIR/helm_build_services.py "$REPODIR"
 
-helm repo index "$REPODIR"
-helm repo update
-
 $DIR/helm_prebuild_compute_kits.py
 $DIR/helm_build_compute_kits.py "$REPODIR"
 
-kill $PID
+#FIXME this really belongs in helm_build_*.
+# This deduplicates templates shrinking the size of
+# the compute-kit package. Otherwise, it blows out the
+# helm release k8s 1m configmap limit.
+D=/tmp/computekit-$$/
+mkdir -p $D
+tar -C $D --exclude "charts/*/kolla-common/templates/*" -xf "$REPODIR/compute-kit-0.6.0-1.tgz"
+pushd "$REPODIR"
+helm package "$D/compute-kit"
+popd
 
-helm search | grep '^kollabuild/'
+helm repo index "$REPODIR"
+helm repo update
