@@ -12,7 +12,6 @@
 # limitations under the License.
 
 import copy
-import errno
 import os
 import subprocess
 import sys
@@ -34,11 +33,14 @@ pod_http_termination = [
     'neutron-server-deployment',
     'nova-api-deployment',
     'nova-novncproxy-deployment',
+    'nova-placement-deployment',
     'cinder-api-deployment',
     'glance-api-deployment',
     'glance-registry-deployment',
     'heat-api-cfn-deployment',
-    'heat-api-deployment'
+    'heat-api-deployment',
+    'ironic-api-deployment',
+    'ironic-inspector-deployment'
 ]
 
 common_mariadb = [
@@ -46,17 +48,37 @@ common_mariadb = [
     'neutron-create-db-job',
     'nova-create-db-job',
     'nova-api-create-db-job',
+    'nova-cell0-create-db-job',
     'cinder-create-db-job',
     'glance-create-db-job',
+    'ironic-api-create-db-job',
+    'ironic-api-manage-db-job',
+    'ironic-inspector-create-db-job',
+    'ironic-inspector-manage-db-job',
+    'heat-create-db-job',
     'cinder-delete-db-job',
     'glance-delete-db-job',
     'keystone-delete-db-job',
     'neutron-delete-db-job',
     'nova-delete-db-job',
-    'nova-api-delete-db-job'
+    'nova-api-delete-db-job',
+    'ironic-api-delete-db-job',
+    'ironic-inspector-delete-db-job',
+    'heat-create-db-job',
+    'heat-delete-db-job'
 ]
 
 common_create_keystone_admin = [
+    'ironic-create-keystone-service-job',
+    'ironic-create-keystone-user-job',
+    'ironic-api-create-keystone-endpoint-public-job',
+    'ironic-api-create-keystone-endpoint-internal-job',
+    'ironic-api-create-keystone-endpoint-admin-job',
+    'ironic-inspector-create-keystone-service-job',
+    'ironic-inspector-create-keystone-user-job',
+    'ironic-inspector-create-keystone-endpoint-public-job',
+    'ironic-inspector-create-keystone-endpoint-internal-job',
+    'ironic-inspector-create-keystone-endpoint-admin-job',
     'neutron-create-keystone-service-job',
     'neutron-create-keystone-endpoint-public-job',
     'neutron-create-keystone-endpoint-internal-job',
@@ -73,6 +95,11 @@ common_create_keystone_admin = [
     'nova-create-keystone-endpoint-public-job',
     'nova-create-keystone-endpoint-internal-job',
     'nova-create-keystone-endpoint-admin-job',
+    'nova-placement-create-keystone-user-job',
+    'nova-placement-create-keystone-service-job',
+    'nova-placement-create-keystone-endpoint-public-job',
+    'nova-placement-create-keystone-endpoint-internal-job',
+    'nova-placement-create-keystone-endpoint-admin-job',
     'cinder-create-keystone-service-job',
     'cinder-create-keystone-servicev2-job',
     'cinder-create-keystone-endpoint-public-job',
@@ -89,12 +116,28 @@ common_create_keystone_admin = [
     'neutron-delete-keystone-service-job',
     'neutron-delete-keystone-user-job',
     'nova-delete-keystone-service-job',
-    'nova-delete-keystone-user-job'
+    'nova-delete-keystone-user-job',
+    'ironic-inspector-delete-keystone-service-job',
+    'ironic-inspector-delete-keystone-user-job',
+    'ironic-delete-keystone-service-job',
+    'ironic-delete-keystone-user-job',
+    'heat-create-keystone-user-job',
+    'heat-create-keystone-service-job',
+    'heat-create-keystone-endpoint-public-job',
+    'heat-create-keystone-endpoint-internal-job',
+    'heat-create-keystone-endpoint-admin-job',
+    'heat-delete-keystone-user-job',
+    'heat-delete-keystone-service-job',
+    'heat-cfn-create-keystone-service-job',
+    'heat-cfn-create-keystone-endpoint-public-job',
+    'heat-cfn-create-keystone-endpoint-internal-job',
+    'heat-cfn-create-keystone-endpoint-admin-job',
+    'heat-cfn-delete-keystone-service-job'
 ]
 
 
-def helm_build_package(repodir, srcdir):
-    command_line = "cd %s; helm package %s" % (repodir, srcdir)
+def helm_dep_up(srcdir):
+    command_line = "cd %s; helm dep up --skip-refresh" % (srcdir)
     try:
         res = subprocess.check_output(
             command_line, shell=True,
@@ -137,13 +180,8 @@ def main():
             sys.stdout.write("\rProcessing %i/%i" % (count, len(packages)))
             sys.stdout.flush()
             count += 1
-        pkgchartdir = os.path.join(microdir, package, "charts")
-        try:
-            os.makedirs(pkgchartdir)
-        except OSError as e:
-            if e.errno != errno.EEXIST:
-                raise
-        helm_build_package(pkgchartdir, os.path.join(srcdir, "kolla-common"))
+        pkgdir = os.path.join(microdir, package)
+        helm_dep_up(pkgdir)
         pkg_values = copy.deepcopy(values['common'])
         if package in common_create_keystone_admin:
             key = 'common-create-keystone-admin'
