@@ -1,6 +1,6 @@
 #!/bin/bash -xe
 
-PACKAGE_VERSION=0.5.0-1
+PACKAGE_VERSION=0.6.0-1
 DISTRO="$2"
 TYPE="$3"
 CONFIG="$4"
@@ -17,7 +17,7 @@ fi
 
 if [ "x$BRANCH" == "xt" ]; then
     echo Version: $BRANCH is not implemented yet.
-    exit -1
+    exit 1
 fi
 
 if [ "x$BRANCH" == "x3" ]; then
@@ -31,8 +31,8 @@ if [ "x$4" == "xiscsi" ]; then
 fi
 
 if [ "x$4" == "xhelm-operator" ]; then
-    echo "helm operator job is not yet implemented..."
-    exit -1
+    echo "Not yet implemented..."  "$CONFIG" "$DISTRO" "$BRANCH"
+    exit 1
 fi
 
 if [ "x$4" == "xhelm-compute-kit" ]; then
@@ -40,6 +40,11 @@ if [ "x$4" == "xhelm-compute-kit" ]; then
     exit 0
 fi
 
+if [ "x$4" == "xironic" ]; then
+    tools/setup_gate_iscsi.sh $1 $2 $3 $4 $5 $BRANCH $PIPELINE
+    exit 0
+fi
+
 #
 # Starting default config CEPH
 #
