@@ -1,4 +1,6 @@
 #!/bin/bash
+
+DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )/" && pwd )"
 [ ! -d ../kolla ] && pushd .. && git clone https://github.com/openstack/kolla-ansible && mv kolla-ansible kolla && popd
 grep api_interface_address ../kolla/etc/kolla/globals.yml || echo api_interface_address: "0.0.0.0" >> ../kolla/etc/kolla/globals.yml
 grep tunnel_interface_address ../kolla/etc/kolla/globals.yml || echo tunnel_interface_address: "0.0.0.0" >> ../kolla/etc/kolla/globals.yml
@@ -6,9 +8,10 @@ grep orchestration_engine ../kolla/etc/kolla/globals.yml || echo orchestration_e
 #sudo yum install -y golang-bin || sudo apt-get install -y golang
 #tools/build_helm_templates.sh
 set -x
+. tools/helm_versions.sh
 mkdir -p ~/.helm/plugins/template
-curl -L -o /tmp/helm-template.tar.gz https://github.com/technosophos/helm-template/releases/download/2.1.3%2B1/helm-template-linux.tgz
-curl -L -o /tmp/helm.tar.gz https://storage.googleapis.com/kubernetes-helm/helm-v2.1.3-linux-amd64.tar.gz
+curl -L -o /tmp/helm-template.tar.gz "$HELM_TEMPLATE_URL"
+curl -L -o /tmp/helm.tar.gz "$HELM_URL"
 mkdir -p ~/bin
 tar --strip-components 1 -C ~/bin linux-amd64/helm -zxf /tmp/helm.tar.gz
 tar -C ~/.helm/plugins/template/ -zxf /tmp/helm-template.tar.gz
